/****************************************************************************
**
** Copyright (C) 2006 Trolltech ASA. All rights reserved.
**
** This file is part of the documentation of Qt. It was originally
** published as part of Qt Quarterly.
**
** This file may be used under the terms of the GNU General Public License
** version 2.0 as published by the Free Software Foundation or under the
** terms of the Qt Commercial License Agreement. The respective license
** texts for these are provided with the open source and commercial
** editions of Qt.
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#include <QtGui/QAction>
#include <QtGui/QFileDialog>
#include <QtGui/QMenuBar>
#include <QtGui/QKeySequence>
#include "moviewidget.h"
#include "window.h"

Window::Window(QWidget *parent)
    : QWidget(parent)
{
    createActions();

    setupUi(this);
    movieWidget = new MovieWidget(this);
    connect(this, SIGNAL(movieChosen(QString)),
            movieWidget, SLOT(loadMovie(QString)));
    connect(movieWidget, SIGNAL(optimalSizeChange()),
            this, SLOT(updateSizes()));
    layout()->addWidget(movieWidget);
    visibleCheckBox->setChecked(movieWidget->nativeControlsVisible());
}

Window::~Window()
{
}

void Window::updateSizes()
{
    adjustSize();
}

void Window::on_visibleCheckBox_toggled(bool newValue)
{
    movieWidget->setNativeControlsVisible(newValue);
}

void Window::createActions()
{
    QMenuBar *menuBar = new QMenuBar(0); // Will become the main menubar
    QMenu *fileMenu = menuBar->addMenu(tr("File"));
    QAction *openAction = fileMenu->addAction(tr("Open..."));
    openAction->setShortcut(QKeySequence(QKeySequence::Open));
    connect(openAction, SIGNAL(activated()), this, SLOT(chooseMovie()));
    fileMenu->addSeparator();
    QAction *closeAction = fileMenu->addAction(tr("Close..."));
    closeAction->setShortcut(QKeySequence(QKeySequence::Close));
    connect(closeAction, SIGNAL(activated()), this, SLOT(close()));
}

void Window::chooseMovie()
{
    QString fileName = QFileDialog::getOpenFileName(this);
    if (!fileName.isEmpty())
        emit movieChosen(fileName);
}

void Window::resizeEvent(QResizeEvent *)
{
    controllerSizeLabel->setText(tr("%1x%2").arg(movieWidget->width()).arg(movieWidget->height()));
    optimalSizeLabel->setText(tr("%1x%2").arg(movieWidget->sizeHint().width()).arg(movieWidget->sizeHint().height()));
}
