/****************************************************************************
**
** Copyright (C) 2006 Trolltech ASA. All rights reserved.
**
** This file is part of the documentation of Qt. It was originally
** published as part of Qt Quarterly.
**
** This file may be used under the terms of the GNU General Public License
** version 2.0 as published by the Free Software Foundation or under the
** terms of the Qt Commercial License Agreement. The respective license
** texts for these are provided with the open source and commercial
** editions of Qt.
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#include "webwidget.h"
#include <QtCore/QUrl>
#include <WebKit/WebKit.h>
#include <WebKit/CarbonUtils.h>
#include <WebKit/HIWebView.h>
#include <Carbon/Carbon.h>

WebWidget::WebWidget(QWidget *parent)
    : QWidget(parent)
{
    HIViewRef webView;
    WebInitForCarbon();
    HIWebViewCreate(&webView);
    create(WId(webView));
}

WebWidget::~WebWidget()
{
}

void WebWidget::setUrl(const QUrl &url)
{
    if (!url.isValid())
        return;

    QString qurlString = url.toString();
    CFStringRef urlString = CFStringCreateWithCharacters(0, reinterpret_cast<const UniChar *>(qurlString.unicode()), qurlString.size());
    CFURLRef urlRef = CFURLCreateWithString(0, urlString, 0);

    WebView *cocoaView = HIWebViewGetWebView(HIViewRef(winId()));
    NSURLRequest *request = [NSURLRequest requestWithURL:(NSURL *)urlRef];
    [[cocoaView mainFrame] loadRequest:request];

    CFRelease(urlString);
    CFRelease(urlRef);
}

void WebWidget::goForward()
{
    WebView *cocoaView = HIWebViewGetWebView(HIViewRef(winId()));
    [cocoaView goForward];
}

void WebWidget::goBackward()
{
    WebView *cocoaView = HIWebViewGetWebView(HIViewRef(winId()));
    [cocoaView goBack];
}
